package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.UserSessions;

/**
 * 用户会话Mapper接口
 * 
 * @author ruoyi
 * @date 2024-01-01
 */
public interface UserSessionsMapper 
{
    /**
     * 查询用户会话
     * 
     * @param sessionId 用户会话ID
     * @return 用户会话
     */
    public UserSessions selectUserSessionsById(String sessionId);

    /**
     * 查询用户会话列表
     * 
     * @param userSessions 用户会话
     * @return 用户会话集合
     */
    public List<UserSessions> selectUserSessionsList(UserSessions userSessions);

    /**
     * 新增用户会话
     * 
     * @param userSessions 用户会话
     * @return 结果
     */
    public int insertUserSessions(UserSessions userSessions);

    /**
     * 修改用户会话
     * 
     * @param userSessions 用户会话
     * @return 结果
     */
    public int updateUserSessions(UserSessions userSessions);

    /**
     * 删除用户会话
     * 
     * @param sessionId 用户会话ID
     * @return 结果
     */
    public int deleteUserSessionsById(String sessionId);

    /**
     * 批量删除用户会话
     * 
     * @param sessionIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteUserSessionsByIds(String[] sessionIds);
}